@@ -1,13 +1,12 @@
 package JiftyX::Fixtures::Script;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use strict;
 use warnings;
 
+use App::CLI;
+use base qw(App::CLI App::CLI::Command);
 
-sub dispatch {
-
-}
 
 1;
 
@@ -18,7 +17,7 @@ JiftyX::Fixtures::Script
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 AUTHOR
 
